@@ -24,7 +24,7 @@ def sentiment(txt, arg):
 def transformers_sentiment(txt):
     sentiment_analysis = pipeline("sentiment-analysis")
     result = sentiment_analysis(pos_text)[0]
-    result = ({"Label:": result['label'], "Confidence Score:", result['score']})
+    result = ({"Label:": result['label'], "Confidence Score:": result['score']})
     return result
 
 #def pos_neg_sentiment(txt):
